@@ -5,7 +5,7 @@ use Moo 'with';
 
 with 'Bubblegum::Role::Configuration';
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 sub import {
     my $target = caller;
@@ -27,7 +27,7 @@ Bubblegum - Opinionated Modern Perl Development Framework
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -48,78 +48,59 @@ is equivalent to
 with the exception that Bubblegum implements it's own autoboxing architecture.
 The Bubblegum autobox classes are the foundation for this development framework.
 The decision to re-implement many core and autobox functions was based on the
-desire to build-in data validation and design a system using object-roles for
-a higher level of abstraction. The following functionality is made available
-simply by using Bubblegum:
+desire to build-in data validation and design a system using roles for a higher
+level of abstraction. The following functionality is made available simply by
+using Bubblegum:
 
     # integers
 
-        my $range = 10->to(1); # [ 10, 9, 8, 7, 6, 5, 4, 3, 2, 1 ]
+        my $range = 5->to(1);                   # [ 5, 4, 3, 2, 1 ]
 
     # floats
 
-        my $strip = 3.1415927->incr->int; # 4
+        my $strip = 3.1415927->incr->int;       # 4
 
     # strings
 
-        my $greet = 'hello world'->titlecase; # "Hello World"
+        my $greet = 'hello world'->titlecase;   # "Hello World"
 
     # arrays
 
         my $alpha = ['a'..'z'];
-        my $map   = $alpha->keyed(1..26); # { 1=>'a', 2='b', ...}
+        my $map   = $alpha->keyed(1..26);       # { 1=>'a', 2='b', ...}
 
     # hashes
 
-        my $map = { 1=>'a', 2=>'b', 3=>'c', ...};
-        $map->reset->set(1 => 'z'); # { 1=>'z', 2=undef, 3=>undef, ...}
+        my $map = { 1=>'a', 2=>'b', 3=>'c' };
+        $map->reset->set(1 => 'z');             # { 1=>'z', 2=undef, 3=>undef }
 
     # routines
 
         my $code = ['a'..'z']->iterator;
-        my $char = $code->call;
+        my $char = $code->call;                 # a
 
     # comparison operations
 
-        my $ten = "10";             # string containing the number 10
-        $ten->eqtv(10)              # false, strict compare type/value mismatch
-        $ten->eq(10)                # true, value comparison with coercion
-        10->eq($ten)                # true, same as above
-        "10"->type                  # string
-        (10)->type                  # integer
-        10->typeof('nil')           # false
-        10->typeof('num')           # true
-        10->typeof('str')           # false
+        my $ten = "10";                         # string containing the 10
+        $ten->eqtv(10)                          # false, type/value mismatch
+        $ten->eq(10)                            # true, coercive comparison
+        10->eq($ten)                            # true, same as above
+        "10"->type                              # string
+        (10)->type                              # integer
+        10->typeof('aref')                      # false
+        10->typeof('cref')                      # false
+        10->typeof('href')                      # false
+        10->typeof('int')                       # true
+        10->typeof('nil')                       # false
+        10->typeof('null')                      # false
+        10->typeof('num')                       # true
+        10->typeof('str')                       # false
 
-    # include Moo as your default object-system
+    # include Moo as your default object-system (optional)
 
-        use Bubblegum::Class;       # with Moo
-        use Bubblegum::Role;        # with Moo::Role
-        use Bubblegum::Singleton;   # with Moo + Cached Instance
-
-    # the gum function (for your convenience)
-
-        say gum->script;            # Running /opt/app/repl
-
-    # no more $FindBin::RealBin
-
-        BEGIN {
-            use Bubblegum;
-            use lib gum->lib;       # equivalent to ./bin/lib
-        }
-
-    # assuming your script is located in a bin directory one level down
-    # from where your lib directory is ...
-    # or
-
-        BEGIN {
-            use Bubblegum;
-            use lib gum->lib(1);    # equivalent to ./bin/../lib
-        }
-
-    # et al
-
-        say [@INC]->join("\n");
+        use Bubblegum::Class;                   # with Moo
+        use Bubblegum::Role;                    # with Moo::Role
+        use Bubblegum::Singleton;               # with Moo + Cached Instance
 
 =head1 DESCRIPTION
 
@@ -149,17 +130,53 @@ higher-level of abstraction and consistency.
 
 =head1 FEATURES
 
-    * 5.10.0 required
-    * core functions throw exceptions
-    * autoboxing with more consistent method names
-    * file and path utilities
-    * date and time utilities
-    * encoding/decoding utilities
-    * default utf-8 encoding for all IO operations
-    * modern method order resolution
-    * modern minimalistic object system
-    * strict syntax checking
-    * global utility object
+=over 4
+
+=item *
+
+Requires 5.10.0
+
+=item *
+
+Enforces Strict Syntax and Enables Warnings
+
+=item *
+
+Core Functions Throw Exceptions
+
+=item *
+
+Autoboxing With Consistent Functions Names
+
+=item *
+
+File and Path Utilities
+
+=item *
+
+Date and Time Utilities
+
+=item *
+
+Encoding and Decoding Utilities
+
+=item *
+
+UTF-8 Encoding For All IO Operations
+
+=item *
+
+Modern Method Order Resolution
+
+=item *
+
+Modern Minimalistic Object System
+
+=item *
+
+Classified Optional Features and Enhancements
+
+=back
 
 =head1 RATIONALE
 
@@ -174,35 +191,6 @@ Enforced consistency is a path many other programming languages and frameworks
 have adopted to great effect, so Bubblegum is one approach towards that end in
 Perl.
 
-=head2 Bubblegum Manifesto
-
-    * develop locally, avoid system perl (try perlbrew, plenv, locallib, etc)
-    * adopt an object-system, avoid rolling your own OO
-    * always enable the strict and warnings pragmas
-    * avoid variable-length routine arguments and return values
-    * die honorably, with structured exceptions not strings
-
-=head2 Bubblegum Environment Object
-
-Bubblegum has an environment object, an instance of a kind-of utility class
-containing methods which carry-out common programming tasks that are not
-intrinsically tied to a particular data type. This utility object is made
-accessible via the automatically exported gum function ("gum"), and is a
-Bubblegum::Environment object, which also provides information about the system
-and runtime environment. The global gum object is meant to provide easy access
-to common routines, e.g., file and path routines, date and time routines, access
-to environment variables and user information, as well as many other utility
-functions like dumping and encoding data. This functions will be made available
-once Bubblegum has been loaded unless it is already defined. There are lots of
-handy methods which can be called on this object. The gum function (i.e. the
-environment object) is useful for making common routines available to your
-program without polluting the calling class' namespace.
-
-    use Bubblegum;
-
-    my $payday = gum->date('next friday');
-    say 'My paycheck will be deposited on', $payday;
-
 =head2 Bubblegum Topology
 
 Bubblegum type classes are built as extensions to the autobox type classes. The
@@ -270,57 +258,57 @@ L<Bubblegum::Wrapper::Dumper> for Perl serialization,
 L<Bubblegum::Wrapper::Encoder> for content encoding, L<Bubblegum::Wrapper::Json>
 for JSON serialization and L<Bubblegum::Wrapper::Yaml> for YAML serialization.
 
-=head2 Bubblegum Type Methods
+=head2 Bubblegum Data Type Operations
 
-The following methods will can be called on their associated data type as if
-the native types were blessed objects.
+The following classes have methods which can be invoked by variables containing
+data of a type corresponding with the type the class is designed to handle.
 
-=head3 Array Methods
+=head3 Array Operations
 
-Array methods work on arrays and array references. Please see
-L<Bubblegum::Object::Array> for more information on methods associated with
+Array operations work on arrays and array references. Please see
+L<Bubblegum::Object::Array> for more information on operations associated with
 array references.
 
-=head3 Code Methods
+=head3 Code Operations
 
-Code methods work on code references. Please see L<Bubblegum::Object::Code> for
-more information on methods associated with code references.
+Code operations work on code references. Please see L<Bubblegum::Object::Code>
+for more information on operations associated with code references.
 
-=head3 Hash Methods
+=head3 Hash Operations
 
-Hash methods work on hash and hash references. Please see
-L<Bubblegum::Object::Hash> for more information on methods associated with hash
-references.
+Hash operations work on hash and hash references. Please see
+L<Bubblegum::Object::Hash> for more information on operations associated with
+hash references.
 
-=head3 Integer Methods
+=head3 Integer Operations
 
-Integer methods work on integer and number data. Please see
-L<Bubblegum::Object::Integer> for more information on methods associated with
+Integer operations work on integer and number data. Please see
+L<Bubblegum::Object::Integer> for more information on operations associated with
 integers.
 
-=head3 Number Methods
+=head3 Number Operations
 
-Number methods work on data that meets the criteria for being a number. Please
-see L<Bubblegum::Object::Number> for more information on methods associated
-with numbers.
+Number operations work on data that meets the criteria for being a number.
+Please see L<Bubblegum::Object::Number> for more information on operations
+associated with numbers.
 
-=head3 String Methods
+=head3 String Operations
 
-String methods work on data that meets the criteria for being a string. Please
-see L<Bubblegum::Object::String> for more information on methods associated
-with strings.
+String operations work on data that meets the criteria for being a string.
+Please see L<Bubblegum::Object::String> for more information on operations
+associated with strings.
 
-=head3 Undef Methods
+=head3 Undef Operations
 
-Undef methods work on variables whose value is undefined. Note, undef methods
-do not work on undef directly. Please see L<Bubblegum::Object::Undef> for more
-information on methods associated with undefined variables.
+Undef operations work on variables whose value is undefined. Note, undef
+operations do not work on undef directly. Please see L<Bubblegum::Object::Undef>
+for more information on operations associated with undefined variables.
 
-=head3 Universal Methods
+=head3 Universal Operations
 
-Universal methods work on all data which meets the criteria for being defined.
-Please see L<Bubblegum::Object::Universal> for more information on methods
-associated with array references.
+Universal operations work on all data which meets the criteria for being
+defined. Please see L<Bubblegum::Object::Universal> for more information on
+operations associated with array references.
 
 =head1 AUTHOR
 
