@@ -8,7 +8,7 @@ with 'Bubblegum::Object::Role::Defined';
 with 'Bubblegum::Object::Role::Comparison';
 with 'Bubblegum::Object::Role::Value';
 
-our $VERSION = '0.08'; # VERSION
+our $VERSION = '0.09'; # VERSION
 
 
 
@@ -154,7 +154,7 @@ sub reverse {
 sub rindex {
     my ($self, $substr, $pos) = @_;
     bbblgm::chkstr $substr;
-    return CORE::rindex $self, $substr if scalar @_ == 2;
+    return CORE::rindex $self, $substr if !defined $pos;
 
     bbblgm::chknum $pos;
     return CORE::rindex $self, $substr, $pos;
@@ -173,10 +173,10 @@ sub snakecase {
 sub split {
     my ($self, $regexp, $limit) = @_;
     bbblgm::chkre $regexp;
-    return [CORE::split $regexp, $self] if scalar @_ == 2;
+    return [CORE::split /$regexp/, $self] if !defined $limit;
 
     bbblgm::chknum $limit;
-    return [CORE::split $regexp, $self, $limit];
+    return [CORE::split /$regexp/, $self, $limit];
 }
 
 
@@ -208,7 +208,7 @@ sub to_code {
 
 sub to_hash {
     my $self = CORE::shift;
-    goto {"$self"=>"$self"};
+    return {"$self"=>"$self"};
 }
 
 
@@ -265,7 +265,7 @@ Bubblegum::Object::String - Common Methods for Operating on Strings
 
 =head1 VERSION
 
-version 0.08
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -440,7 +440,7 @@ The length method returns the number of characters within the subject.
 =head2 lines
 
     my $string = "who am i?\nwhere am i?\nhow did I get here";
-    $string->lines; # ['who am i','where am i','how did i get here']
+    $string->lines; # ['who am i?','where am i?','how did i get here']
 
 The lines method breaks the subject into pieces, split on 1 or more newline characters, and returns an array reference consisting of the pieces.
 
@@ -463,12 +463,12 @@ the opposite order.
 
     my $string = 'explain the unexplainable';
     $string->rindex('explain'); # 14
-    $string->rindex('explain', 0); # 14
-    $string->rindex('explain', 1); # 14
-    $string->rindex('explain', 2); # 14
-    $string->rindex('explain', 2); # 14
+    $string->rindex('explain', 0); # 0
+    $string->rindex('explain', 21); # 14
+    $string->rindex('explain', 22); # 14
+    $string->rindex('explain', 23); # 14
     $string->rindex('explain', 20); # 14
-    $string->rindex('explain', 14); # 14
+    $string->rindex('explain', 14); # 0
     $string->rindex('explain', 13); # 0
     $string->rindex('explain', 0); # 0
     $string->rindex('explained'); # -1
@@ -494,8 +494,8 @@ modifies the subject.
 =head2 split
 
     my $string = 'name, age, dob, email';
-    $self->split(qr/\,\s*/); # ['name', 'age', 'dob', 'email']
-    $self->split(qr/\,\s*/, 2); # ['name', 'age']
+    $string->split(qr/\,\s*/); # ['name', 'age', 'dob', 'email']
+    $string->split(qr/\,\s*/, 2); # ['name', 'age, dob, email']
 
 The split method splits the subject into a list of strings, separating each
 chunk by the argument (regexp object), and returns that list as an array
@@ -505,7 +505,7 @@ argument to be a Regexp object.
 
 =head2 strip
 
-    my $string = 'one  , two  , three';
+    my $string = 'one,  two,  three';
     $string->strip; # one, two, three
 
 The strip method returns the subject replacing occurences of 2 or more
@@ -595,7 +595,7 @@ The uppercase method is an alias to the uc method.
 =head2 words
 
     my $string = "is this a bug we're experiencing";
-    $self->words; # ["is","this","a","bug","we're","experiencing"]
+    $string->words; # ["is","this","a","bug","we're","experiencing"]
 
 The words method splits the subject into a list of strings, separating each
 group of characters by 1 or more consecutive spaces, and returns that list as an
